package com.aucma.report.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.aucma.common.utils.DateUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.report.domain.RecordQualityMaterial;
import com.aucma.report.service.IRecordQualityMaterialService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

/**
 * 质检材料信息Controller
 *
 * @author Yinq
 * @date 2024-01-07
 */
@RestController
@RequestMapping("/report/qualityMaterial" )
public class RecordQualityMaterialController extends BaseController {
    @Autowired
    private IRecordQualityMaterialService recordQualityMaterialService;

    /**
     * 查询质检材料信息列表
     */
    @PreAuthorize("@ss.hasPermi('report:qualityMaterial:list')" )
    @GetMapping("/list" )
    public TableDataInfo list(RecordQualityMaterial recordQualityMaterial) {
        startPage();
        List<RecordQualityMaterial> list = recordQualityMaterialService.selectRecordQualityMaterialList(recordQualityMaterial);
        return getDataTable(list);
    }

    /**
     * 导出质检材料信息列表
     */
    @PreAuthorize("@ss.hasPermi('report:qualityMaterial:export')" )
    @Log(title = "质检材料信息" , businessType = BusinessType.EXPORT)
    @PostMapping("/export" )
    public void export(HttpServletResponse response, RecordQualityMaterial recordQualityMaterial) {
        List<RecordQualityMaterial> list = recordQualityMaterialService.selectRecordQualityMaterialList(recordQualityMaterial);
        ExcelUtil<RecordQualityMaterial> util = new ExcelUtil<RecordQualityMaterial>(RecordQualityMaterial. class);
        util.exportExcel(response, list, "质检材料信息数据" );
    }

    /**
     * 获取质检材料信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('report:qualityMaterial:query')" )
    @GetMapping(value = "/{objId}" )
    public AjaxResult getInfo(@PathVariable("objId" ) Long objId) {
        return success(recordQualityMaterialService.selectRecordQualityMaterialByObjId(objId));
    }

    /**
     * 新增质检材料信息
     */
    @PreAuthorize("@ss.hasPermi('report:qualityMaterial:add')" )
    @Log(title = "质检材料信息" , businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RecordQualityMaterial recordQualityMaterial) {
        recordQualityMaterial.setCreatedBy(getUsername());
        recordQualityMaterial.setCreatedTime(DateUtils.getNowDate());
        return toAjax(recordQualityMaterialService.insertRecordQualityMaterial(recordQualityMaterial));
    }

    /**
     * 修改质检材料信息
     */
    @PreAuthorize("@ss.hasPermi('report:qualityMaterial:edit')" )
    @Log(title = "质检材料信息" , businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RecordQualityMaterial recordQualityMaterial) {
        recordQualityMaterial.setUpdatedBy(getUsername());
        recordQualityMaterial.setUpdatedTime(DateUtils.getNowDate());
        return toAjax(recordQualityMaterialService.updateRecordQualityMaterial(recordQualityMaterial));
    }

    /**
     * 删除质检材料信息
     */
    @PreAuthorize("@ss.hasPermi('report:qualityMaterial:remove')" )
    @Log(title = "质检材料信息" , businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}" )
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(recordQualityMaterialService.deleteRecordQualityMaterialByObjIds(objIds));
    }
}
